remove: Remove Leaflet.Glify elements from a map

removeR Documentation

Remove Leaflet.Glify elements from a map

Description

Remove one or more features from a map, identified by 'layerId'; or, clear all features of the given group.

Usage

removeGlPoints(map, layerId)

removeGlPolylines(map, layerId)

removeGlPolygons(map, layerId)

clearGlLayers(map)

clearGlGroup(map, group)

Arguments

map

a map widget object, possibly created from leaflet() but more likely from leafletProxy()

layerId

character vector; the layer id(s) of the item to remove

group

the name of the group whose members should be removed

Value

the new 'map' object


leafgl documentation built on April 15, 2026, 5:06 p.m.