| remove | R Documentation |
Remove one or more features from a map, identified by 'layerId'; or, clear all features of the given group.
removeGlPoints(map, layerId)
removeGlPolylines(map, layerId)
removeGlPolygons(map, layerId)
clearGlLayers(map)
clearGlGroup(map, group)
map |
a map widget object, possibly created from |
layerId |
character vector; the layer id(s) of the item to remove |
group |
the name of the group whose members should be removed |
the new 'map' object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.